require 'nuge/clients/urbanairship'

describe Nuge::Clients::Urbanairship do
  describe '#initialize' do
    it 'passes initialization options directly to the pusher class' do
      client  = Nuge::Clients::Urbanairship.new(
        application_key:    'applicationkey',
        application_secret: 'applicationsecret',
        master_secret:      'mastersecret'
      )

      expect(Urbanairship).to receive(:application_key=).with('applicationkey')
      expect(Urbanairship).to receive(:application_secret=).with('applicationsecret')
      expect(Urbanairship).to receive(:master_secret=).with('mastersecret')

      client.pusher
    end
  end

  describe '#register' do
    it 'forwards the registration call through the pusher' do
      client = Nuge::Clients::Urbanairship.new

      expect(client.pusher).to receive(:register_device).with('1234', {})

      client.register('1234')
    end
  end

  describe '#unregister' do
    it 'forwards the unregistration call through the pusher' do
      client = Nuge::Clients::Urbanairship.new

      expect(client.pusher).to receive(:unregister_device).with('1234', {})

      client.unregister('1234')
    end
  end

  describe '#push' do
    it 'forwards client configured payloads through the pusher, assuming apns' do
      client = Nuge::Clients::Urbanairship.new
      message = { 'alert' => 'hello', 'some_id' => '99' }

      expect(client.pusher).to receive(:push).with(
        device_tokens: ['1234'],
        aps: message
      )

      client.push(['1234'], message)
    end

    it 'allows the payload to be configured with a formatter' do
      client = Nuge::Clients::Urbanairship.new
      message = { 'alert' => 'hello', 'some_id' => '99' }

      expect(client.pusher).to receive(:push).with(
        ids: ['1234'],
        message: message
      )

      formatter = -> (ids, messsage) do
        { ids: ids, message: message }
      end

      client.push(['1234'], message.merge(formatter: formatter))
    end
  end
end
